==> delphixpy-1.11.8.0-py2.py3-none-any.whl: delphixpy/v1_7_0/web/jetstream/usage/branch/branch.py <==
# coding: utf8
#
# Copyright 2021 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "jetstream.usage.branch"
"""
API_VERSION = "1.7.0"

try:
    from urllib import urlencode 
except ImportError:
    from urllib.parse import urlencode 
from delphixpy.v1_7_0 import response_validator

def list_branch_usage_data(engine, data_container=None):
    """
    Lists the usage breakdown for Jet Stream branches belonging to the given
    container.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
    :param data_container: The usage information for the branches on this data
        container will be returned.
    :type data_container: ``TEXT_TYPE``
    :rtype: ``list`` of :py:class:`v1_7_0.web.vo.JSBranchUsageData`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/jetstream/usage/branch/listBranchUsageData"
    query_params = {"dataContainer": data_container}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['JSBranchUsageData'], returns_list=True, raw_result=raw_result)

==> delphixpy-1.11.19.0-py2.py3-none-any.whl: delphixpy/v1_7_1/web/jetstream/usage/branch/branch.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "jetstream.usage.branch"
"""
API_VERSION = "1.7.1"

from urllib.parse import urlencode
from delphixpy.v1_7_1 import response_validator

def list_branch_usage_data(engine, data_container=None):
    """
    Lists the usage breakdown for Jet Stream branches belonging to the given
    container.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_7_1.delphix_engine.DelphixEngine`
    :param data_container: The usage information for the branches on this data
        container will be returned.
    :type data_container: ``str``
    :rtype: ``list`` of :py:class:`v1_7_1.web.vo.JSBranchUsageData`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/jetstream/usage/branch/listBranchUsageData"
    query_params = {"dataContainer": data_container}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['JSBranchUsageData'], returns_list=True, raw_result=raw_result)
